@@ -46,6 +46,7 @@ def quoteStrings(s):
 # import models into model package
 from .active_directory import ActiveDirectory
 from .active_directory_get_response import ActiveDirectoryGetResponse
+from .active_directory_patch import ActiveDirectoryPatch
 from .active_directory_post import ActiveDirectoryPost
 from .active_directory_response import ActiveDirectoryResponse
 from .admin import Admin
@@ -130,9 +131,13 @@ from .connection import Connection
 from .connection_get_response import ConnectionGetResponse
 from .connection_post import ConnectionPost
 from .connection_response import ConnectionResponse
+from .container_default_protection import ContainerDefaultProtection
+from .container_default_protection_get_response import ContainerDefaultProtectionGetResponse
+from .container_default_protection_response import ContainerDefaultProtectionResponse
 from .controller import Controller
 from .controller_get_response import ControllerGetResponse
 from .controllers import Controllers
+from .default_protection_reference import DefaultProtectionReference
 from .destroyed_patch_post import DestroyedPatchPost
 from .directory import Directory
 from .directory_export import DirectoryExport
@@ -168,6 +173,7 @@ from .directorypolicypost_policies import DirectorypolicypostPolicies
 from .dns import Dns
 from .dns_get_response import DnsGetResponse
 from .dns_patch import DnsPatch
+from .dns_post import DnsPost
 from .dns_response import DnsResponse
 from .drive import Drive
 from .drive_get_response import DriveGetResponse
@@ -237,8 +243,25 @@ from .network_interface_performance import NetworkInterfacePerformance
 from .network_interface_performance_eth import NetworkInterfacePerformanceEth
 from .network_interface_performance_fc import NetworkInterfacePerformanceFc
 from .network_interface_performance_get_response import NetworkInterfacePerformanceGetResponse
+from .network_interface_port_details import NetworkInterfacePortDetails
+from .network_interface_port_details_rx_los import NetworkInterfacePortDetailsRxLos
+from .network_interface_port_details_rx_power import NetworkInterfacePortDetailsRxPower
+from .network_interface_port_details_static import NetworkInterfacePortDetailsStatic
+from .network_interface_port_details_static_rx_power_thresholds import NetworkInterfacePortDetailsStaticRxPowerThresholds
+from .network_interface_port_details_static_temperature_thresholds import NetworkInterfacePortDetailsStaticTemperatureThresholds
+from .network_interface_port_details_static_tx_bias_thresholds import NetworkInterfacePortDetailsStaticTxBiasThresholds
+from .network_interface_port_details_static_tx_power_thresholds import NetworkInterfacePortDetailsStaticTxPowerThresholds
+from .network_interface_port_details_static_voltage_thresholds import NetworkInterfacePortDetailsStaticVoltageThresholds
+from .network_interface_port_details_temperature import NetworkInterfacePortDetailsTemperature
+from .network_interface_port_details_tx_bias import NetworkInterfacePortDetailsTxBias
+from .network_interface_port_details_tx_fault import NetworkInterfacePortDetailsTxFault
+from .network_interface_port_details_tx_power import NetworkInterfacePortDetailsTxPower
+from .network_interface_port_details_voltage import NetworkInterfacePortDetailsVoltage
 from .network_interface_post import NetworkInterfacePost
 from .network_interface_response import NetworkInterfaceResponse
+from .network_interfaces_port_details import NetworkInterfacesPortDetails
+from .network_interfaces_port_details_get_response import NetworkInterfacesPortDetailsGetResponse
+from .network_interfaces_port_details_response import NetworkInterfacesPortDetailsResponse
 from .networkinterfacepatch_eth import NetworkinterfacepatchEth
 from .networkinterfacepost_eth import NetworkinterfacepostEth
 from .new_name import NewName
@@ -256,10 +279,13 @@ from .page_info import PageInfo
 from .performance import Performance
 from .pod import Pod
 from .pod_array_status import PodArrayStatus
+from .pod_eradication_config import PodEradicationConfig
 from .pod_get_response import PodGetResponse
 from .pod_patch import PodPatch
 from .pod_performance import PodPerformance
 from .pod_performance_by_array import PodPerformanceByArray
+from .pod_performance_by_array_get_response import PodPerformanceByArrayGetResponse
+from .pod_performance_get_response import PodPerformanceGetResponse
 from .pod_performance_replication import PodPerformanceReplication
 from .pod_performance_replication_by_array import PodPerformanceReplicationByArray
 from .pod_performance_replication_by_array_get_response import PodPerformanceReplicationByArrayGetResponse
@@ -290,6 +316,11 @@ from .policy_member_export_response import PolicyMemberExportResponse
 from .policy_member_get_response import PolicyMemberGetResponse
 from .policy_member_post import PolicyMemberPost
 from .policy_member_response import PolicyMemberResponse
+from .policy_nfs import PolicyNfs
+from .policy_nfs_get_response import PolicyNfsGetResponse
+from .policy_nfs_patch import PolicyNfsPatch
+from .policy_nfs_post import PolicyNfsPost
+from .policy_nfs_response import PolicyNfsResponse
 from .policy_patch import PolicyPatch
 from .policy_post import PolicyPost
 from .policy_response import PolicyResponse
@@ -299,6 +330,7 @@ from .policy_rule_nfs_client_post import PolicyRuleNfsClientPost
 from .policy_rule_nfs_client_response import PolicyRuleNfsClientResponse
 from .policy_rule_quota import PolicyRuleQuota
 from .policy_rule_quota_get_response import PolicyRuleQuotaGetResponse
+from .policy_rule_quota_patch import PolicyRuleQuotaPatch
 from .policy_rule_quota_post import PolicyRuleQuotaPost
 from .policy_rule_quota_response import PolicyRuleQuotaResponse
 from .policy_rule_smb_client import PolicyRuleSmbClient
@@ -317,6 +349,7 @@ from .policy_smb_response import PolicySmbResponse
 from .policymemberexportpost_members import PolicymemberexportpostMembers
 from .policymemberpost_members import PolicymemberpostMembers
 from .policyrulenfsclientpost_rules import PolicyrulenfsclientpostRules
+from .policyrulequotapatch_rules import PolicyrulequotapatchRules
 from .policyrulequotapost_rules import PolicyrulequotapostRules
 from .policyrulesmbclientpost_rules import PolicyrulesmbclientpostRules
 from .policyrulesnapshotpost_rules import PolicyrulesnapshotpostRules
@@ -325,7 +358,9 @@ from .port_common import PortCommon
 from .port_get_response import PortGetResponse
 from .port_initiator import PortInitiator
 from .port_initiators_get_response import PortInitiatorsGetResponse
+from .priority_adjustment import PriorityAdjustment
 from .protection_group import ProtectionGroup
+from .protection_group_eradication_config import ProtectionGroupEradicationConfig
 from .protection_group_get_response import ProtectionGroupGetResponse
 from .protection_group_performance import ProtectionGroupPerformance
 from .protection_group_performance_array import ProtectionGroupPerformanceArray
@@ -392,6 +427,14 @@ from .resource_space_get_response import ResourceSpaceGetResponse
 from .resource_space_no_id import ResourceSpaceNoId
 from .resource_space_no_id_get_response import ResourceSpaceNoIdGetResponse
 from .retention_policy import RetentionPolicy
+from .saml2_sso import Saml2Sso
+from .saml2_sso_get_response import Saml2SsoGetResponse
+from .saml2_sso_idp import Saml2SsoIdp
+from .saml2_sso_patch import Saml2SsoPatch
+from .saml2_sso_post import Saml2SsoPost
+from .saml2_sso_response import Saml2SsoResponse
+from .saml2_sso_sp import Saml2SsoSp
+from .saml2_sso_sp_credential import Saml2SsoSpCredential
 from .session import Session
 from .session_get_response import SessionGetResponse
 from .smis import Smis
@@ -476,6 +519,7 @@ from .test_result_get_response import TestResultGetResponse
 from .test_result_response import TestResultResponse
 from .test_result_with_resource import TestResultWithResource
 from .test_result_with_resource_get_response import TestResultWithResourceGetResponse
+from .test_result_with_resource_patch_response import TestResultWithResourcePatchResponse
 from .test_result_with_resource_response import TestResultWithResourceResponse
 from .throttle import Throttle
 from .time_window import TimeWindow
@@ -483,6 +527,10 @@ from .total_item_count_response import TotalItemCountResponse
 from .transfer import Transfer
 from .username import Username
 from .username_response import UsernameResponse
+from .virtual_machine import VirtualMachine
+from .virtual_machine_get_response import VirtualMachineGetResponse
+from .virtual_machine_post import VirtualMachinePost
+from .virtual_machine_response import VirtualMachineResponse
 from .volume import Volume
 from .volume_common import VolumeCommon
 from .volume_diff import VolumeDiff
