@@ -36,6 +36,7 @@ from .models.array_connection_post import ArrayConnectionPost
 from .models.array_encryption import ArrayEncryption
 from .models.array_factory_reset_token import ArrayFactoryResetToken
 from .models.array_performance import ArrayPerformance
+from .models.array_performance_by_link import ArrayPerformanceByLink
 from .models.array_space import ArraySpace
 from .models.arrayencryption_data_at_rest import ArrayencryptionDataAtRest
 from .models.arrays import Arrays
@@ -51,12 +52,15 @@ from .models.chap import Chap
 from .models.cloud_provider_tag import CloudProviderTag
 from .models.connection import Connection
 from .models.connection_post import ConnectionPost
+from .models.container_default_protection import ContainerDefaultProtection
 from .models.controller import Controller
 from .models.controllers import Controllers
+from .models.default_protection_reference import DefaultProtectionReference
 from .models.destroyed_patch_post import DestroyedPatchPost
 from .models.directory import Directory
 from .models.directory_export import DirectoryExport
 from .models.directory_export_post import DirectoryExportPost
+from .models.directory_lock_nlm_reclamation import DirectoryLockNlmReclamation
 from .models.directory_patch import DirectoryPatch
 from .models.directory_performance import DirectoryPerformance
 from .models.directory_policy_export_post import DirectoryPolicyExportPost
@@ -105,6 +109,16 @@ from .models.kmip_patch import KmipPatch
 from .models.kmip_post import KmipPost
 from .models.kmip_test_result import KmipTestResult
 from .models.limited_by import LimitedBy
+from .models.local_group import LocalGroup
+from .models.local_group_membership_post import LocalGroupMembershipPost
+from .models.local_group_post import LocalGroupPost
+from .models.local_member import LocalMember
+from .models.local_user import LocalUser
+from .models.local_user_membership_post import LocalUserMembershipPost
+from .models.local_user_patch import LocalUserPatch
+from .models.local_user_post import LocalUserPost
+from .models.localgroupmembershippost_members import LocalgroupmembershippostMembers
+from .models.localusermembershippost_groups import LocalusermembershippostGroups
 from .models.maintenance_window import MaintenanceWindow
 from .models.maintenance_window_post import MaintenanceWindowPost
 from .models.member import Member
@@ -117,7 +131,22 @@ from .models.network_interface_patch import NetworkInterfacePatch
 from .models.network_interface_performance import NetworkInterfacePerformance
 from .models.network_interface_performance_eth import NetworkInterfacePerformanceEth
 from .models.network_interface_performance_fc import NetworkInterfacePerformanceFc
+from .models.network_interface_port_details import NetworkInterfacePortDetails
+from .models.network_interface_port_details_rx_los import NetworkInterfacePortDetailsRxLos
+from .models.network_interface_port_details_rx_power import NetworkInterfacePortDetailsRxPower
+from .models.network_interface_port_details_static import NetworkInterfacePortDetailsStatic
+from .models.network_interface_port_details_static_rx_power_thresholds import NetworkInterfacePortDetailsStaticRxPowerThresholds
+from .models.network_interface_port_details_static_temperature_thresholds import NetworkInterfacePortDetailsStaticTemperatureThresholds
+from .models.network_interface_port_details_static_tx_bias_thresholds import NetworkInterfacePortDetailsStaticTxBiasThresholds
+from .models.network_interface_port_details_static_tx_power_thresholds import NetworkInterfacePortDetailsStaticTxPowerThresholds
+from .models.network_interface_port_details_static_voltage_thresholds import NetworkInterfacePortDetailsStaticVoltageThresholds
+from .models.network_interface_port_details_temperature import NetworkInterfacePortDetailsTemperature
+from .models.network_interface_port_details_tx_bias import NetworkInterfacePortDetailsTxBias
+from .models.network_interface_port_details_tx_fault import NetworkInterfacePortDetailsTxFault
+from .models.network_interface_port_details_tx_power import NetworkInterfacePortDetailsTxPower
+from .models.network_interface_port_details_voltage import NetworkInterfacePortDetailsVoltage
 from .models.network_interface_post import NetworkInterfacePost
+from .models.network_interfaces_port_details import NetworkInterfacesPortDetails
 from .models.networkinterfacepatch_eth import NetworkinterfacepatchEth
 from .models.networkinterfacepost_eth import NetworkinterfacepostEth
 from .models.new_name import NewName
@@ -251,6 +280,8 @@ from .models.software_installation_step import SoftwareInstallationStep
 from .models.software_installation_steps import SoftwareInstallationSteps
 from .models.software_installation_steps_checks import SoftwareInstallationStepsChecks
 from .models.software_installations import SoftwareInstallations
+from .models.software_patch import SoftwarePatch
+from .models.software_patches import SoftwarePatches
 from .models.software_post import SoftwarePost
 from .models.software_upgrade_plan import SoftwareUpgradePlan
 from .models.software_version import SoftwareVersion
@@ -280,6 +311,7 @@ from .models.volume import Volume
 from .models.volume_common import VolumeCommon
 from .models.volume_diff import VolumeDiff
 from .models.volume_group import VolumeGroup
+from .models.volume_group_patch import VolumeGroupPatch
 from .models.volume_group_performance import VolumeGroupPerformance
 from .models.volume_group_post import VolumeGroupPost
 from .models.volume_group_space import VolumeGroupSpace
@@ -331,6 +363,7 @@ CLASSES_TO_ADD_PROPS = [
     ArrayEncryption,
     ArrayFactoryResetToken,
     ArrayPerformance,
+    ArrayPerformanceByLink,
     ArraySpace,
     ArrayencryptionDataAtRest,
     Arrays,
@@ -346,12 +379,15 @@ CLASSES_TO_ADD_PROPS = [
     CloudProviderTag,
     Connection,
     ConnectionPost,
+    ContainerDefaultProtection,
     Controller,
     Controllers,
+    DefaultProtectionReference,
     DestroyedPatchPost,
     Directory,
     DirectoryExport,
     DirectoryExportPost,
+    DirectoryLockNlmReclamation,
     DirectoryPatch,
     DirectoryPerformance,
     DirectoryPolicyExportPost,
@@ -400,6 +436,16 @@ CLASSES_TO_ADD_PROPS = [
     KmipPost,
     KmipTestResult,
     LimitedBy,
+    LocalGroup,
+    LocalGroupMembershipPost,
+    LocalGroupPost,
+    LocalMember,
+    LocalUser,
+    LocalUserMembershipPost,
+    LocalUserPatch,
+    LocalUserPost,
+    LocalgroupmembershippostMembers,
+    LocalusermembershippostGroups,
     MaintenanceWindow,
     MaintenanceWindowPost,
     Member,
@@ -412,7 +458,22 @@ CLASSES_TO_ADD_PROPS = [
     NetworkInterfacePerformance,
     NetworkInterfacePerformanceEth,
     NetworkInterfacePerformanceFc,
+    NetworkInterfacePortDetails,
+    NetworkInterfacePortDetailsRxLos,
+    NetworkInterfacePortDetailsRxPower,
+    NetworkInterfacePortDetailsStatic,
+    NetworkInterfacePortDetailsStaticRxPowerThresholds,
+    NetworkInterfacePortDetailsStaticTemperatureThresholds,
+    NetworkInterfacePortDetailsStaticTxBiasThresholds,
+    NetworkInterfacePortDetailsStaticTxPowerThresholds,
+    NetworkInterfacePortDetailsStaticVoltageThresholds,
+    NetworkInterfacePortDetailsTemperature,
+    NetworkInterfacePortDetailsTxBias,
+    NetworkInterfacePortDetailsTxFault,
+    NetworkInterfacePortDetailsTxPower,
+    NetworkInterfacePortDetailsVoltage,
     NetworkInterfacePost,
+    NetworkInterfacesPortDetails,
     NetworkinterfacepatchEth,
     NetworkinterfacepostEth,
     NewName,
@@ -546,6 +607,8 @@ CLASSES_TO_ADD_PROPS = [
     SoftwareInstallationSteps,
     SoftwareInstallationStepsChecks,
     SoftwareInstallations,
+    SoftwarePatch,
+    SoftwarePatches,
     SoftwarePost,
     SoftwareUpgradePlan,
     SoftwareVersion,
@@ -575,6 +638,7 @@ CLASSES_TO_ADD_PROPS = [
     VolumeCommon,
     VolumeDiff,
     VolumeGroup,
+    VolumeGroupPatch,
     VolumeGroupPerformance,
     VolumeGroupPost,
     VolumeGroupSpace,
