@@ -17,6 +17,7 @@ from . import FA_2_1
 from . import FA_2_6
 from . import FA_2_10
 from . import FA_2_17
+from . import FA_2_21
 from . import FA_2_19
 from . import FA_2_20
 from . import FA_2_16
@@ -38,6 +39,7 @@ fa_modules = {
     '2.6': FA_2_6,
     '2.10': FA_2_10,
     '2.17': FA_2_17,
+    '2.21': FA_2_21,
     '2.19': FA_2_19,
     '2.20': FA_2_20,
     '2.16': FA_2_16,
