@@ -192,8 +192,6 @@ from .models.user import User
 from .models.user_quota import UserQuota
 from .models.user_quota_patch import UserQuotaPatch
 from .models.user_quota_post import UserQuotaPost
-from .models.verification_key import VerificationKey
-from .models.verification_key_patch import VerificationKeyPatch
 
 
 def add_properties(model):
@@ -387,9 +385,7 @@ CLASSES_TO_ADD_PROPS = [
     User,
     UserQuota,
     UserQuotaPatch,
-    UserQuotaPost,
-    VerificationKey,
-    VerificationKeyPatch
+    UserQuotaPost
 ]
 
 if os.environ.get('DOCS_GENERATION') is None:
