@@ -83,6 +83,9 @@ from .array_connection_path import ArrayConnectionPath
 from .array_connection_path_get_response import ArrayConnectionPathGetResponse
 from .array_connection_post import ArrayConnectionPost
 from .array_connection_response import ArrayConnectionResponse
+from .array_encryption import ArrayEncryption
+from .array_encryption_data_at_rest import ArrayEncryptionDataAtRest
+from .array_eradication_config import ArrayEradicationConfig
 from .array_factory_reset_token import ArrayFactoryResetToken
 from .array_factory_reset_token_get_response import ArrayFactoryResetTokenGetResponse
 from .array_factory_reset_token_response import ArrayFactoryResetTokenResponse
@@ -106,7 +109,11 @@ from .audit_response import AuditResponse
 from .blade import Blade
 from .blade_get_response import BladeGetResponse
 from .bucket import Bucket
+from .bucket_defaults import BucketDefaults
+from .bucket_defaults_readonly import BucketDefaultsReadonly
+from .bucket_eradication_config import BucketEradicationConfig
 from .bucket_get_response import BucketGetResponse
+from .bucket_patch import BucketPatch
 from .bucket_performance import BucketPerformance
 from .bucket_performance_get_response import BucketPerformanceGetResponse
 from .bucket_post import BucketPost
@@ -152,14 +159,26 @@ from .directory_service_smb import DirectoryServiceSmb
 from .dns import Dns
 from .dns_get_response import DnsGetResponse
 from .dns_response import DnsResponse
+from .drive import Drive
+from .drive_get_response import DriveGetResponse
 from .eula import Eula
 from .eula_get_response import EulaGetResponse
 from .eula_response import EulaResponse
 from .eula_signature import EulaSignature
+from .file_info import FileInfo
+from .file_lock import FileLock
+from .file_lock_get_response import FileLockGetResponse
+from .file_lock_nlm_reclamation_response import FileLockNlmReclamationResponse
+from .file_lock_range import FileLockRange
+from .file_lock_response import FileLockResponse
 from .file_system import FileSystem
+from .file_system_client import FileSystemClient
+from .file_system_clients_get_response import FileSystemClientsGetResponse
+from .file_system_clients_response import FileSystemClientsResponse
 from .file_system_get_response import FileSystemGetResponse
 from .file_system_group_performance import FileSystemGroupPerformance
 from .file_system_groups_performance_get_response import FileSystemGroupsPerformanceGetResponse
+from .file_system_lock_nlm_reclamation import FileSystemLockNlmReclamation
 from .file_system_patch import FileSystemPatch
 from .file_system_performance import FileSystemPerformance
 from .file_system_performance_get_response import FileSystemPerformanceGetResponse
@@ -180,6 +199,7 @@ from .file_system_users_performance_get_response import FileSystemUsersPerforman
 from .fixed_location_reference import FixedLocationReference
 from .fixed_reference import FixedReference
 from .fixed_reference_name_only import FixedReferenceNameOnly
+from .fixed_reference_no_id import FixedReferenceNoId
 from .fixed_reference_no_resource_type import FixedReferenceNoResourceType
 from .fixed_reference_with_remote import FixedReferenceWithRemote
 from .group import Group
@@ -221,6 +241,9 @@ from .linkaggregationgroup import Linkaggregationgroup
 from .location_reference import LocationReference
 from .login import Login
 from .login_banner_get_response import LoginBannerGetResponse
+from .logs_async import LogsAsync
+from .logs_async_get_response import LogsAsyncGetResponse
+from .logs_async_response import LogsAsyncResponse
 from .member import Member
 from .member_link import MemberLink
 from .multi_protocol import MultiProtocol
@@ -228,10 +251,17 @@ from .multi_protocol_post import MultiProtocolPost
 from .network_interface import NetworkInterface
 from .network_interface_get_response import NetworkInterfaceGetResponse
 from .network_interface_patch import NetworkInterfacePatch
+from .network_interface_ping import NetworkInterfacePing
+from .network_interface_ping_get_response import NetworkInterfacePingGetResponse
+from .network_interface_ping_response import NetworkInterfacePingResponse
 from .network_interface_response import NetworkInterfaceResponse
+from .network_interface_trace import NetworkInterfaceTrace
+from .network_interface_trace_get_response import NetworkInterfaceTraceGetResponse
+from .network_interface_trace_response import NetworkInterfaceTraceResponse
 from .nfs import Nfs
 from .nfs_export_policy import NfsExportPolicy
 from .nfs_export_policy_get_response import NfsExportPolicyGetResponse
+from .nfs_export_policy_post import NfsExportPolicyPost
 from .nfs_export_policy_response import NfsExportPolicyResponse
 from .nfs_export_policy_rule import NfsExportPolicyRule
 from .nfs_export_policy_rule_base import NfsExportPolicyRuleBase
@@ -241,6 +271,9 @@ from .nfs_export_policy_rule_response import NfsExportPolicyRuleResponse
 from .nfs_patch import NfsPatch
 from .oauth_token_response import OauthTokenResponse
 from .object_backlog import ObjectBacklog
+from .object_lock_config_base import ObjectLockConfigBase
+from .object_lock_config_request_body import ObjectLockConfigRequestBody
+from .object_lock_config_response import ObjectLockConfigResponse
 from .object_store_access_key import ObjectStoreAccessKey
 from .object_store_access_key_get_response import ObjectStoreAccessKeyGetResponse
 from .object_store_access_key_post import ObjectStoreAccessKeyPost
@@ -258,6 +291,8 @@ from .object_store_access_policy_rule_get_response import ObjectStoreAccessPolic
 from .object_store_access_policy_rule_response import ObjectStoreAccessPolicyRuleResponse
 from .object_store_account import ObjectStoreAccount
 from .object_store_account_get_response import ObjectStoreAccountGetResponse
+from .object_store_account_patch import ObjectStoreAccountPatch
+from .object_store_account_post import ObjectStoreAccountPost
 from .object_store_account_response import ObjectStoreAccountResponse
 from .object_store_remote_credential_get_resp import ObjectStoreRemoteCredentialGetResp
 from .object_store_remote_credentials import ObjectStoreRemoteCredentials
@@ -274,6 +309,7 @@ from .permission import Permission
 from .policy import Policy
 from .policy_base import PolicyBase
 from .policy_base_get_response import PolicyBaseGetResponse
+from .policy_base_renameable import PolicyBaseRenameable
 from .policy_base_response import PolicyBaseResponse
 from .policy_file_system_snapshot import PolicyFileSystemSnapshot
 from .policy_file_system_snapshot_get_response import PolicyFileSystemSnapshotGetResponse
@@ -330,6 +366,7 @@ from .snmp_v2c import SnmpV2c
 from .snmp_v3 import SnmpV3
 from .snmp_v3_post import SnmpV3Post
 from .space import Space
+from .space_extended import SpaceExtended
 from .subnet import Subnet
 from .subnet_get_response import SubnetGetResponse
 from .subnet_response import SubnetResponse
@@ -360,3 +397,7 @@ from .user_quota_get_response import UserQuotaGetResponse
 from .user_quota_patch import UserQuotaPatch
 from .user_quota_post import UserQuotaPost
 from .user_quota_response import UserQuotaResponse
+from .verification_key import VerificationKey
+from .verification_key_get_response import VerificationKeyGetResponse
+from .verification_key_patch import VerificationKeyPatch
+from .verification_key_response import VerificationKeyResponse
